Ghid configurare - Numele cartii (si al site-ului daca se publica in internet)
Author: Autorul cartii

Skip to content

# Organizarea si configurarea cartii

In aceasta pagina veti gasi o serie de indicatii pentru configurarea si structurarea cartii dvs.

## Configurarea cartii

...tbd indicatii...

## Structurarea si continutul cartii

Pastrati un singur nivel de strucuturare si navigare. Folositi-va de facilitatea "cuprins" (TOC) care este "calculat" la nivel de pagina. Acest lucru va permite o navigare mai clara si usoara si clara pentru cititor.

Mentiniti cit puteti de mult doua n9vele de titluri in fiecare pagina a cartii. Sigur ca puteti crea oricite nivele de titluri doriti, dar recomandarea de 2 nivele de titluri este una cu caracter practic si denota o organizare concisa si "la obiect" a cartii in mintea dvs. Este exact ceea ce faceti prin "designul cartii" inainte xe elaborare (si pe masura elaborarii): sa in epeti prin a face "schita" unui cuprins... Veti intelege mai bine scopul, ceea ce vreti sa spuneti prin carte si va va ajuta sa ramineti focalizat pe scopul cartii.

## Legaturi ;link-uri) in carte

Puteti crea linkuri intre diverse pagini. Recomandarea noastra este sa folositi o adresare relativa in specificareaa fisierului destinatie a legaturii. Pentru urilizarea adresarii relative aveti in vedere ca radacina cartii dvs este directorul `doc_src/`. Primul director specificat in link fara a fi precedat de caraterul `/` este considerat imediat (adiacent) sub radacina.

Aici este un exemplu de legatura catre o gagina din directorul curent marcata "in lucru" exemplu ce demonstreaza utilizarea legaturior: Exemplu de pagina marcata "in lucru"

## Materiale ajutatoare existente

In sablonul de creare a unei carti noi au fos puse la dispozitie:

- acest ghid
- o poza (`pictures/wip.png`) ce sugereaza conceptul de "in lucru..." ce o puteti folosi in procesul de redactare a cartii dvs si astfel sa puteti publica partial cartea pastrind partile nefinalizate si marcindu-le ca "in lucru":
- directorul `pictures/` ce se recomanda pentru pastrarea tuturor imaginilor ce le veti folosi in cartea dvs. Pastrarea "la comun" a tuturor pozelor va permite o revizuire mai usoara a acestora si degrevarea directoarelir cu paginile cartii de informatii ce va pot distrage focalizarea de la continutul efectiv.

Last update: October 15, 2025